@@ -582,6 +582,9 @@ def explain_diffs(old, new, indent="", prefix=""):
     for 'ip access-list ...' (where no extra string is required) or
     something like 'ip prefix-list NAME', where these are required.
 
+    If either of the two lists supplied are None, an empty list is
+    assumed, either removing or adding all the entries.
+
     The return value is a list of lines these explaining comments
     inserte4d.  The lines without comments will create the new list.
     """
@@ -597,7 +600,7 @@ def explain_diffs(old, new, indent="", prefix=""):
     # difflib.Differ.compare, which adds a character at the start,
     # explaining if a line is added, removed or the same, followed by
     # a space
-    for line in _differ.compare(old, new):
+    for line in _differ.compare(old or [], new or []):
         op, text = line[0], line[2:]
 
         if op ==" ":
